import * as i0 from '@angular/core';
import { InjectionToken, inject, PLATFORM_ID, Injectable, ChangeDetectorRef, DestroyRef, Pipe, NgModule, makeEnvironmentProviders } from '@angular/core';
import { BehaviorSubject, distinctUntilChanged, of, catchError, switchMap, shareReplay, map, combineLatest, first, firstValueFrom } from 'rxjs';
import { isPlatformBrowser } from '@angular/common';
import { HttpClient } from '@angular/common/http';
import { takeUntilDestroyed } from '@angular/core/rxjs-interop';

var TranslateFeatureKind;
(function (TranslateFeatureKind) {
    TranslateFeatureKind[TranslateFeatureKind["DEFAULT_LANGUAGE"] = 0] = "DEFAULT_LANGUAGE";
    TranslateFeatureKind[TranslateFeatureKind["DEFAULT_UNDEFINED_OR_NULL_BOOLEAN_TO"] = 1] = "DEFAULT_UNDEFINED_OR_NULL_BOOLEAN_TO";
    TranslateFeatureKind[TranslateFeatureKind["DEFAULT_UNDEFINED_KEY_TO"] = 2] = "DEFAULT_UNDEFINED_KEY_TO";
    TranslateFeatureKind[TranslateFeatureKind["ASSETS_PATH"] = 3] = "ASSETS_PATH";
    TranslateFeatureKind[TranslateFeatureKind["REMEMBER_LANGUAGE"] = 4] = "REMEMBER_LANGUAGE";
    TranslateFeatureKind[TranslateFeatureKind["AUTO_TRANSLATED_LANGUAGES"] = 5] = "AUTO_TRANSLATED_LANGUAGES";
    TranslateFeatureKind[TranslateFeatureKind["LIBRE_TRANSLATE"] = 6] = "LIBRE_TRANSLATE";
})(TranslateFeatureKind || (TranslateFeatureKind = {}));

const TRANSLATE_ASSETS_PATH = new InjectionToken('TRANSLATE_ASSETS_PATH', {
    factory: () => 'assets/i18n/',
});
function withAssetsPath(assetsPath) {
    return {
        kind: TranslateFeatureKind.ASSETS_PATH,
        providers: [{ provide: TRANSLATE_ASSETS_PATH, useValue: assetsPath }],
    };
}

const TRANSLATE_AUTO_TRANSLATED_LANGUAGES = new InjectionToken('TRANSLATE_AUTO_TRANSLATED_LANGUAGES', {
    factory: () => [],
});
function withAutoTranslatedLanguages(autoTranslatedLanguages) {
    return {
        kind: TranslateFeatureKind.AUTO_TRANSLATED_LANGUAGES,
        providers: [{ provide: TRANSLATE_AUTO_TRANSLATED_LANGUAGES, useValue: autoTranslatedLanguages }],
    };
}

const TRANSLATE_DEFAULT_LANGUAGE = new InjectionToken('TRANSLATE_DEFAULT_LANGUAGE', {
    factory: () => 'en',
});
function withDefaultLanguage(language) {
    return {
        kind: TranslateFeatureKind.DEFAULT_LANGUAGE,
        providers: [{ provide: TRANSLATE_DEFAULT_LANGUAGE, useValue: language }],
    };
}

const TRANSLATE_DEFAULT_UNDEFINED_OR_NULL_BOOLEAN_TO = new InjectionToken('TRANSLATE_DEFAULT_UNDEFINED_OR_NULL_BOOLEAN_TO', {
    factory: () => null,
});
function withDefaultUndefinedOrNullBooleanTo(defaultUndefinedOrNullBooleanTo) {
    return {
        kind: TranslateFeatureKind.DEFAULT_UNDEFINED_OR_NULL_BOOLEAN_TO,
        providers: [{ provide: TRANSLATE_DEFAULT_UNDEFINED_OR_NULL_BOOLEAN_TO, useValue: defaultUndefinedOrNullBooleanTo }],
    };
}

const TRANSLATE_DEFAULT_UNDEFINED_KEY_TO = new InjectionToken('TRANSLATE_DEFAULT_UNDEFINED_KEY_TO', {
    factory: () => '',
});
function withDefaultUndefinedKeyTo(defaultUndefinedOKeyTo) {
    return {
        kind: TranslateFeatureKind.DEFAULT_UNDEFINED_KEY_TO,
        providers: [{ provide: TRANSLATE_DEFAULT_UNDEFINED_KEY_TO, useValue: defaultUndefinedOKeyTo }],
    };
}

const TRANSLATE_LIBRE_TRANSLATE_INSTANCE_URL = new InjectionToken('TRANSLATE_LIBRE_TRANSLATE_INSTANCE_URL', {
    factory: () => undefined,
});
function withLibreTranslate(libreTranslateInstanceUrl) {
    return {
        kind: TranslateFeatureKind.LIBRE_TRANSLATE,
        providers: [{ provide: TRANSLATE_LIBRE_TRANSLATE_INSTANCE_URL, useValue: libreTranslateInstanceUrl }],
    };
}

const TRANSLATE_REMEMBER_LANGUAGE = new InjectionToken('TRANSLATE_REMEMBER_LANGUAGE', {
    factory: () => true,
});
function withRememberLanguage(rememberLanguage) {
    return {
        kind: TranslateFeatureKind.REMEMBER_LANGUAGE,
        providers: [{ provide: TRANSLATE_REMEMBER_LANGUAGE, useValue: rememberLanguage }],
    };
}

const TRANSLATE_LOCALSTORAGE_KEY = 'language';

class TranslateStore {
    constructor() {
        this.httpClient = inject(HttpClient);
        this.isBrowser = isPlatformBrowser(inject(PLATFORM_ID));
        this.rememberLanguage = inject(TRANSLATE_REMEMBER_LANGUAGE);
        this.defaultLanguage = inject(TRANSLATE_DEFAULT_LANGUAGE);
        this.assetsPath = inject(TRANSLATE_ASSETS_PATH);
        this.autoTranslatedLanguages = inject(TRANSLATE_AUTO_TRANSLATED_LANGUAGES);
        this.selectedLanguage = new BehaviorSubject(this.isBrowser
            ? this.rememberLanguage
                ? localStorage.getItem(TRANSLATE_LOCALSTORAGE_KEY) ?? this.defaultLanguage
                : this.defaultLanguage
            : this.defaultLanguage);
        this.selectedLanguage$ = this.selectedLanguage.pipe(distinctUntilChanged());
        this.translations$ = this.selectedLanguage$.pipe(switchMap((language) => this.httpClient.get(`${this.assetsPath}${language}.json`).pipe(catchError(() => of({})))), shareReplay(1));
        this.autoGeneratedTranslations$ = this.selectedLanguage$.pipe(switchMap((language) => this.autoTranslatedLanguages.includes(language)
            ? this.httpClient.get(`${this.assetsPath}${language}_auto.json`).pipe(catchError(() => of({})))
            : of({})), shareReplay(1));
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.1.3", ngImport: i0, type: TranslateStore, deps: [], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "17.1.3", ngImport: i0, type: TranslateStore, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.1.3", ngImport: i0, type: TranslateStore, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root',
                }]
        }] });

function _dfxTranslate$() {
    const store = inject(TranslateStore);
    const defaultUndefinedKeyTo = inject(TRANSLATE_DEFAULT_UNDEFINED_KEY_TO);
    return (key) => {
        if (!key) {
            return of(defaultUndefinedKeyTo);
        }
        return combineLatest([
            store.translations$.pipe(map((translations) => translations[key])),
            store.autoGeneratedTranslations$.pipe(map((translations) => translations[key])),
        ]).pipe(switchMap(([translation, autoGeneratedTranslation]) => of(translation ?? autoGeneratedTranslation ?? key)));
    };
}
const DFX_TRANSLATE$ = new InjectionToken('dfxTranslate$', {
    providedIn: 'root',
    factory: () => _dfxTranslate$(),
});
function dfxTranslate$() {
    return inject(DFX_TRANSLATE$);
}

class AsyncTranslatePipe {
    constructor() {
        this.ref = inject(ChangeDetectorRef);
        this.destroyRef = inject(DestroyRef);
    }
}

class DfxTr extends AsyncTranslatePipe {
    constructor() {
        super(...arguments);
        this.translate = dfxTranslate$();
    }
    transform(key) {
        if (!this.translation) {
            this.translate(key)
                .pipe(takeUntilDestroyed(this.destroyRef))
                .subscribe((translation) => {
                this.translation = translation;
                this.ref.markForCheck();
            });
        }
        return this.translation ?? '';
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.1.3", ngImport: i0, type: DfxTr, deps: null, target: i0.ɵɵFactoryTarget.Pipe }); }
    static { this.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "17.1.3", ngImport: i0, type: DfxTr, isStandalone: true, name: "tr", pure: false }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.1.3", ngImport: i0, type: DfxTr, decorators: [{
            type: Pipe,
            args: [{
                    name: 'tr',
                    standalone: true,
                    pure: false,
                }]
        }] });

function dfxAutoTranslate$() {
    const httpClient = inject(HttpClient);
    const store = inject(TranslateStore);
    const defaultLanguage = inject(TRANSLATE_DEFAULT_LANGUAGE);
    const libreTranslateInstanceUrl = inject(TRANSLATE_LIBRE_TRANSLATE_INSTANCE_URL);
    const defaultUndefinedKeyTo = inject(TRANSLATE_DEFAULT_UNDEFINED_KEY_TO);
    return (key) => {
        if (!key) {
            return of(defaultUndefinedKeyTo);
        }
        if (libreTranslateInstanceUrl) {
            return store.selectedLanguage$.pipe(switchMap((selectedLanguage) => httpClient
                .put(`${libreTranslateInstanceUrl}/translate`, {
                format: 'text',
                q: key,
                target: selectedLanguage,
                source: defaultLanguage,
            })
                .pipe(map((it) => it.translatedText))), first());
        }
        return of('Feature disabled');
    };
}

class DfxTrA extends AsyncTranslatePipe {
    constructor() {
        super(...arguments);
        this.autoTranslate = dfxAutoTranslate$();
    }
    transform(key) {
        if (!this.translation) {
            this.autoTranslate(key)
                .pipe(takeUntilDestroyed(this.destroyRef))
                .subscribe((translation) => {
                this.translation = translation;
                this.ref.markForCheck();
            });
        }
        return this.translation ?? '';
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.1.3", ngImport: i0, type: DfxTrA, deps: null, target: i0.ɵɵFactoryTarget.Pipe }); }
    static { this.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "17.1.3", ngImport: i0, type: DfxTrA, isStandalone: true, name: "tra", pure: false }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.1.3", ngImport: i0, type: DfxTrA, decorators: [{
            type: Pipe,
            args: [{
                    name: 'tra',
                    standalone: true,
                    pure: false,
                }]
        }] });

class DfxTrB extends AsyncTranslatePipe {
    constructor() {
        super(...arguments);
        this.defaultUndefinedOrNullBooleanTo = inject(TRANSLATE_DEFAULT_UNDEFINED_OR_NULL_BOOLEAN_TO);
        this.translate = dfxTranslate$();
    }
    transform(value) {
        let key = '';
        if (value === undefined || value === null) {
            if (this.defaultUndefinedOrNullBooleanTo === null) {
                return '';
            }
            key = this.defaultUndefinedOrNullBooleanTo ? 'TRUE' : 'FALSE';
        }
        else {
            key = value ? 'TRUE' : 'FALSE';
        }
        if (!this.translation) {
            this.translate(key)
                .pipe(takeUntilDestroyed(this.destroyRef))
                .subscribe((translation) => {
                this.translation = translation;
                this.ref.markForCheck();
            });
        }
        return this.translation ?? '';
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.1.3", ngImport: i0, type: DfxTrB, deps: null, target: i0.ɵɵFactoryTarget.Pipe }); }
    static { this.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "17.1.3", ngImport: i0, type: DfxTrB, isStandalone: true, name: "trb", pure: false }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.1.3", ngImport: i0, type: DfxTrB, decorators: [{
            type: Pipe,
            args: [{
                    name: 'trb',
                    standalone: true,
                    pure: false,
                }]
        }] });

function dfxTranslateSetLanguage() {
    const isBrowser = isPlatformBrowser(inject(PLATFORM_ID));
    const rememberLanguage = inject(TRANSLATE_REMEMBER_LANGUAGE);
    const store = inject(TranslateStore);
    return (language) => {
        store.selectedLanguage.next(language);
        if (isBrowser && rememberLanguage) {
            localStorage.setItem(TRANSLATE_LOCALSTORAGE_KEY, language);
        }
    };
}

function dfxTranslate() {
    const translate$ = dfxTranslate$();
    return (key) => firstValueFrom(translate$(key));
}

class DfxTranslateModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.1.3", ngImport: i0, type: DfxTranslateModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "17.1.3", ngImport: i0, type: DfxTranslateModule, imports: [DfxTr, DfxTrB, DfxTrA], exports: [DfxTr, DfxTrB, DfxTrA] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "17.1.3", ngImport: i0, type: DfxTranslateModule }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.1.3", ngImport: i0, type: DfxTranslateModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [DfxTr, DfxTrB, DfxTrA],
                    exports: [DfxTr, DfxTrB, DfxTrA],
                }]
        }] });

function provideDfxTranslate(...features) {
    return makeEnvironmentProviders([features.map((it) => it.providers)]);
}

/**
 * Generated bundle index. Do not edit.
 */

export { DfxTr, DfxTrA, DfxTrB, DfxTranslateModule, TRANSLATE_ASSETS_PATH, TRANSLATE_AUTO_TRANSLATED_LANGUAGES, TRANSLATE_DEFAULT_LANGUAGE, TRANSLATE_DEFAULT_UNDEFINED_KEY_TO, TRANSLATE_DEFAULT_UNDEFINED_OR_NULL_BOOLEAN_TO, TRANSLATE_LIBRE_TRANSLATE_INSTANCE_URL, TRANSLATE_LOCALSTORAGE_KEY, TRANSLATE_REMEMBER_LANGUAGE, TranslateFeatureKind, TranslateStore, dfxAutoTranslate$, dfxTranslate, dfxTranslate$, dfxTranslateSetLanguage, provideDfxTranslate, withAssetsPath, withAutoTranslatedLanguages, withDefaultLanguage, withDefaultUndefinedKeyTo, withDefaultUndefinedOrNullBooleanTo, withLibreTranslate, withRememberLanguage };
//# sourceMappingURL=dfx-translate.mjs.map
